@@ -769,4 +769,22 @@ class IOViewSet(viewsets.ModelViewSet):
 
 
 def video_streams(request):
-    return render(request, "streams.html", None)
\ No newline at end of file
+    return render(request, "streams.html", None)
+
+from django.contrib.auth import login, authenticate
+from django.contrib.auth.forms import UserCreationForm
+from django.shortcuts import render, redirect
+
+def signup(request):
+    if request.method == 'POST':
+        form = UserCreationForm(request.POST)
+        if form.is_valid():
+            form.save()
+            username = form.cleaned_data.get('username')
+            raw_password = form.cleaned_data.get('password1')
+            user = authenticate(username=username, password=raw_password)
+            login(request, user)
+            return redirect('home')
+    else:
+        form = UserCreationForm()
+    return render(request, 'registration/signup.html', {'form': form})
\ No newline at end of file
